pitchtools.list_ordered_named_chromatic_pitch_pairs_from_expr_1_to_expr_2
=========================================================================

.. autofunction:: abjad.tools.pitchtools.list_ordered_named_chromatic_pitch_pairs_from_expr_1_to_expr_2.list_ordered_named_chromatic_pitch_pairs_from_expr_1_to_expr_2
